@@ -412,6 +412,9 @@ def get_default_parser(usage="%prog [options] <start|stop|status>"):
     parser.add_option(
         "--debug", action="store_true",
         help="Run in the foreground, log to stdout")
+    parser.add_option(
+        "--syslog", action="store_true",
+        help="Write logs to syslog")
     parser.add_option(
         "--nodaemon", action="store_true",
         help="Run in the foreground")
